### Test Scripts


Execute all tests from the repository root:

    pip install -r tests/requirements.txt
    pytest tests


### Running single tests

Directly execute the scripts, e.g.

    pytest tests/test_simple.py
